@@ -16,14 +16,14 @@ def bbox_from_cid(country_id):
     :param country_id: 'africa', 'ame' or a country_id as number
     :return: bounding box rounded to 1 decimal point
     """
-    GLOBE = []
+    GLOBE = [-180, 210, -64, 84]
     BBOX_AFRICA = [-18.5, 52.0, -35.5, 38.0]
     BBOX_AME = [-18.5, 64.0, -35.5, 43.0]
 
     if country_id == 'africa':
         bbox = BBOX_AFRICA
     elif country_id == 'globe':
-        bbox = GLOBE
+        bbox = None
     elif country_id == "ame":
         bbox = BBOX_AME
     else:
@@ -45,7 +45,7 @@ def bbox_from_cid_region(country_id):
     :param country_id: 'africa', 'ame' or a country_id as number
     :return: bounding box rounded to 1 decimal point
     """
-    GLOBE = []
+    GLOBE = [-180, 210, -64, 84]
     BBOX_AFRICA = [-18.5, 52.0, -35.5, 38.0]
     BBOX_AME = [-18.5, 64.0, -35.5, 43.0]
 
