@@ -133,6 +133,8 @@ def make_a_folder(folderpath):
 def make_folders_complete_set(main_folderpath):
     #main folder
     make_a_folder(main_folderpath)
+    #Actual at the EndOfhistory
+    make_a_folder(main_folderpath+'/ActualAtEndOfHistory')
     #Dichotomous subfolders
     make_a_folder(main_folderpath+'/Dichotomous')
     make_a_folder(main_folderpath+'/Dichotomous'+'/Ensemble')
